California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| CAMPAIGN FINANCE: Candidates & Elected Officials
Choose a Listing: Certified Election Candidates Incumbent Elected State Officials Candidates and Elected Officials By Name Who filed a Statement of Intention to run for What State Office? (Filers may not have qualified for the ballot) CalPERS and CalSTRS Candidate Filings, Scanned Images |
Choose an Election Cycle: 2021 through 2022 Historical 2019 through 2020 2017 through 2018 2015 through 2016 2013 through 2014 2011 through 2012 2009 through 2010 2007 through 2008 2005 through 2006 2003 through 2004 2001 through 2002 1999 through 2000
HERE ARE YOUR RESULTS: Election Dates (Dates appear according to the Election Cycle above) 2013 - 2014 Election Dates: 1. SPECIAL ELECTION Tuesday, 1/8/13 2. SPECIAL ELECTION Tuesday, 3/12/13 3. SPECIAL ELECTION Tuesday, 3/12/13 4. SPECIAL ELECTION RUNOFF Tuesday, 5/14/13 5. SPECIAL ELECTION Tuesday, 5/21/13 6. SPECIAL ELECTION Tuesday, 5/21/13 7. SPECIAL ELECTION RUNOFF Tuesday, 7/23/13 8. SPECIAL ELECTION Tuesday, 7/23/13 9. SPECIAL ELECTION RUNOFF Tuesday, 7/30/13 10. SPECIAL ELECTION Tuesday, 9/17/13 11. SPECIAL ELECTION Tuesday, 9/17/13 12. SPECIAL ELECTION Tuesday, 9/24/13 13. SPECIAL ELECTION RUNOFF Tuesday, 9/24/13 14. SPECIAL ELECTION RUNOFF Tuesday, 11/19/13 15. SPECIAL ELECTION RUNOFF Tuesday, 11/19/13 16. SPECIAL ELECTION Tuesday, 12/3/13 17. SPECIAL ELECTION Tuesday, 3/25/14 18. PRIMARY ELECTION Tuesday, 6/3/14 19. SPECIAL ELECTION Monday, 9/29/14 20. GENERAL ELECTION Tuesday, 11/4/14
If you are searching for campaign finance information related to a specific office this is the place to begin. Included are officeholders for Governor, Lieutenant Governor, Secretary of State, Attorney General, State Controller, State Treasurer, Insurance Commissioner, State Superintendent of Public Instruction, Board of Equalization, State Senate, and State Assembly. Here you will find their names, campaign committees, and other information.
STATEWIDE OFFICES
GOVERNOR
BROWN, EDMUND G. (JERRY)
| LIEUTENANT GOVERNOR
NEWSOM, GAVIN
SECRETARY OF STATE
BOWEN, DEBRA
| CONTROLLER
CHIANG, JOHN
TREASURER
LOCKYER, BILL
| ATTORNEY GENERAL
HARRIS, KAMALA D.
SUPERINTENDENT OF PUBLIC INSTRUCTION
TORLAKSON, TOM
| INSURANCE COMMISSIONER
JONES, DAVE
BOARD OF EQUALIZATION
MEMBER BOARD OF EQUALIZATION 01
YEE, BETTY T.
| MEMBER BOARD OF EQUALIZATION 02
RUNNER, GEORGE C.
MEMBER BOARD OF EQUALIZATION 03
STEEL, MICHELLE
| MEMBER BOARD OF EQUALIZATION 04
HORTON, JEROME E.
SENATE DISTRICTS
STATE SENATE 01
GAINES, EDWARD T
| STATE SENATE 02
EVANS, NOREEN M.
STATE SENATE 03
WOLK, LOIS
| STATE SENATE 04
NIELSEN, JIM
STATE SENATE 05
GALGIANI, CATHLEEN
| STATE SENATE 06
STEINBERG, DARRELL
STATE SENATE 07
DE SAULNIER, MARK
| STATE SENATE 08
YEE, LELAND Y.
STATE SENATE 09
HANCOCK, LONI
| STATE SENATE 10
CORBETT, ELLEN
STATE SENATE 11
LENO, MARK
| STATE SENATE 12
CANNELLA, ANTHONY JOSEPH
STATE SENATE 13
HILL, JERRY A.
| STATE SENATE 14
BERRYHILL, TOM
STATE SENATE 15
BEALL, JIM
| STATE SENATE 16
VIDAK, JAMES ANDREW
STATE SENATE 17
MONNING, WILLIAM W.
| STATE SENATE 18
FULLER, JEAN
STATE SENATE 19
JACKSON, HANNAH-BETH
| STATE SENATE 20
PADILLA, ALEX
STATE SENATE 21
KNIGHT, STEVE
| STATE SENATE 22
DE LEON, KEVIN
STATE SENATE 23
VACANT
| STATE SENATE 24
HERNANDEZ, EDWARD P.
STATE SENATE 25
LIU, CAROL
| STATE SENATE 26
MITCHELL, HOLLY J.
STATE SENATE 27
PAVLEY, FRAN
| STATE SENATE 28
LIEU, TED
STATE SENATE 29
HUFF, ROBERT 'BOB'
| STATE SENATE 30
CALDERON, RONALD
STATE SENATE 31
ROTH, RICHARD D.
| STATE SENATE 32
TORRES, NORMA
STATE SENATE 33
LARA, RICARDO
| STATE SENATE 34
CORREA, LOU
STATE SENATE 35
WRIGHT, RODERICK "ROD"
| STATE SENATE 36
ANDERSON, JOEL C.
STATE SENATE 37
WALTERS, MIMI
| STATE SENATE 38
WYLAND, MARK B.
STATE SENATE 39
BLOCK, MARTY J.
| STATE SENATE 40
HUESO, BEN
ASSEMBLY DISTRICTS
ASSEMBLY 01
DAHLE, BRIAN
| ASSEMBLY 02
CHESBRO, WESLEY
ASSEMBLY 03
LOGUE, DANIEL R.
| ASSEMBLY 04
YAMADA, MARIKO M.
ASSEMBLY 05
BIGELOW, FRANK
| ASSEMBLY 06
GAINES, BETH B.
ASSEMBLY 07
DICKINSON, ROGER
| ASSEMBLY 08
ASSEMBLY 09
PAN, RICHARD
| ASSEMBLY 10
LEVINE, MARC
ASSEMBLY 11
FRAZIER, JR., JAMES L
| ASSEMBLY 12
OLSEN, KRISTIN M.
ASSEMBLY 13
EGGMAN, SUSAN
| ASSEMBLY 14
BONILLA, SUSAN
ASSEMBLY 15
SKINNER, NANCY
| ASSEMBLY 16
BUCHANAN, JOAN
ASSEMBLY 17
AMMIANO, TOM
| ASSEMBLY 18
BONTA, ROB
ASSEMBLY 19
TING, PHIL
| ASSEMBLY 20
QUIRK, BILL
ASSEMBLY 21
GRAY, ADAM C.
| ASSEMBLY 22
MULLIN, KEVIN C.
ASSEMBLY 23
PATTERSON, JIM
| ASSEMBLY 24
GORDON, RICHARD S.
ASSEMBLY 25
WIECKOWSKI, ROBERT
| ASSEMBLY 26
CONWAY, CONNIE
ASSEMBLY 27
CAMPOS, NORA ELIA
| ASSEMBLY 28
FONG, PAUL
ASSEMBLY 29
STONE, MARK
| ASSEMBLY 30
ALEJO, LUIS
ASSEMBLY 31
PEREA, HENRY T.
| ASSEMBLY 32
SALAS JR., RUDY
ASSEMBLY 33
DONNELLY, TIM
| ASSEMBLY 34
GROVE, SHANNON
ASSEMBLY 35
ACHADJIAN, KHATCHIK
| ASSEMBLY 36
FOX, STEVE
ASSEMBLY 37
WILLIAMS, DAS
| ASSEMBLY 38
WILK, SCOTT T.
ASSEMBLY 39
BOCANEGRA, RAUL
| ASSEMBLY 40
MORRELL, MIKE
ASSEMBLY 41
HOLDEN, CHRIS
| ASSEMBLY 42
NESTANDE, BRIAN
ASSEMBLY 43
GATTO, MIKE
| ASSEMBLY 44
GORELL, JEFF
ASSEMBLY 45
DABABNEH, MATTHEW
| ASSEMBLY 46
NAZARIAN, ADRIN
ASSEMBLY 47
BROWN, CHERYL
| ASSEMBLY 48
HERNANDEZ, ROGER
ASSEMBLY 49
CHAU, ED
| ASSEMBLY 50
BLOOM, RICHARD
ASSEMBLY 51
GOMEZ, JIMMY
| ASSEMBLY 52
RODRIGUEZ, FREDDIE
ASSEMBLY 53
PEREZ, JOHN A.
| ASSEMBLY 54
RIDLEY-THOMAS, SEBASTIAN
ASSEMBLY 55
HAGMAN, CURT
| ASSEMBLY 56
PEREZ, V. MANUEL
ASSEMBLY 57
CALDERON, IAN
| ASSEMBLY 58
GARCIA, CRISTINA
ASSEMBLY 59
JONES-SAWYER SR., REGINALD BYRON
| ASSEMBLY 60
LINDER, ERIC
ASSEMBLY 61
MEDINA, JOSE J.
| ASSEMBLY 62
BRADFORD, STEVEN
ASSEMBLY 63
RENDON, ANTHONY
| ASSEMBLY 64
HALL, ISADORE
ASSEMBLY 65
QUIRK-SILVA, SHARON
| ASSEMBLY 66
MURATSUCHI, AL
ASSEMBLY 67
MELENDEZ, MELISSA
| ASSEMBLY 68
WAGNER, DON
ASSEMBLY 69
DALY, TOM
| ASSEMBLY 70
LOWENTHAL, BONNIE
ASSEMBLY 71
JONES, BRIAN W.
| ASSEMBLY 72
ALLEN, TRAVIS
ASSEMBLY 73
HARKEY, DIANE
| ASSEMBLY 74
MANSOOR, ALLAN R.
ASSEMBLY 75
WALDRON, MARIE
| ASSEMBLY 76
CHAVEZ, ROCKY
ASSEMBLY 77
MAIENSCHEIN, BRIAN
| ASSEMBLY 78
ATKINS, TONI G.
ASSEMBLY 79
WEBER, SHIRLEY
| ASSEMBLY 80
GONZALEZ, LORENA S.